# -*- coding: utf-8 -*-

from setuptools import setup

setup(
    # name="pythonpinyin",
    name="ppinyin",
    # name="ypinyin",
    # name="py-pinyin",
    version="0.1.0",
    url="https://pypi.org/project/pypinyin/",
    long_description="""Use `pypinyin <https://pypi.org/project/pypinyin/>`_ instead.""",    # noqa
    install_requires=['pypinyin'],
    classifiers=[],
)
